@@ -14,10 +14,12 @@ import time
 
 import board
 import busio
-import digitalio
+
+# import digitalio # Uncomment if your board doesn't support sdcardio
 import storage
 
-import adafruit_sdcard
+# import adafruit_sdcard # Uncomment if your board doesn't support sdcardio
+import sdcardio  # Comment out if your board doesn't support sdcardio
 import adafruit_vc0706
 
 
@@ -30,8 +32,13 @@ IMAGE_FILE = "/sd/image.jpg"  # Full path to file name to save captured image.
 spi = busio.SPI(board.SCK, MOSI=board.MOSI, MISO=board.MISO)
 
 # Setup SD card and mount it in the filesystem.
-sd_cs = digitalio.DigitalInOut(SD_CS_PIN)
-sdcard = adafruit_sdcard.SDCard(spi, sd_cs)
+# Uncomment if your board doesn't support sdcardio
+# sd_cs = digitalio.DigitalInOut(SD_CS_PIN)
+# sdcard = adafruit_sdcard.SDCard(spi, sd_cs)
+sdcard = sdcardio.SDCard(
+    spi, SD_CS_PIN
+)  # Comment out if your board doesn't support sdcardio
+
 vfs = storage.VfsFat(sdcard)
 storage.mount(vfs, "/sd")
 
